@@ -265,23 +265,8 @@ def _build_m06_variant(name: str, polarized: bool, _visited: set[str]):
 XC_UNPOLARIZED = 0
 XC_POLARIZED = 1
 
-
-def _import_pylibxc():
-  """Load the LibXC Python bindings module.
-
-  The distribution published to PyPI will be named ``pylibxc7``, but it
-  exposes the importable module ``pylibxc`` (matching the upstream
-  LibXC project). For local development, users may also have installed
-  a legacy ``pylibxc`` build directly.
-  """
-  try:
-    import pylibxc  # type: ignore[import-not-found]
-    return pylibxc
-  except Exception as e:
-    raise RuntimeError(
-      "The 'pylibxc' module is required to allocate LibXC functionals. "
-      "Install it via the 'pylibxc7' wheels on PyPI or a local build."
-    ) from e
+from ._libxc.functional import LibXCFunctional
+from ._libxc import util as _libxc_util
 
 
 def list_functionals() -> list[str]:
@@ -289,9 +274,9 @@ def list_functionals() -> list[str]:
 
   This is a lightweight convenience wrapper around LibXC's registry:
 
-  - If :mod:`pylibxc7` or :mod:`pylibxc` is available, we return the list from
-    ``pylibxc.util.xc_available_functional_names()``, sorted.
-  - If neither binding is available, we fall back to scanning the
+  - If the bundled LibXC bindings are available, we return the list from
+    ``jxc._libxc.util.xc_available_functional_names()``, sorted.
+  - If that fails, we fall back to scanning the
     ``jxc.functionals`` package for generated Maple modules.
 
   Returns:
@@ -299,8 +284,7 @@ def list_functionals() -> list[str]:
     ``\"gga_x_pbe\"``, ``\"hyb_gga_xc_b3lyp\"``).
   """
   try:
-    pylibxc = _import_pylibxc()
-    return sorted(pylibxc.util.xc_available_functional_names())
+    return sorted(_libxc_util.xc_available_functional_names())
   except Exception:
     # Minimal, best-effort fallback based on generated modules.
     import pkgutil
@@ -364,13 +348,6 @@ def get_params(name, polarized, *ext_params, _visited=None):
     return _build_deorbitalized(name, polarized, _visited)
   if name in _M06_PARAM_SETS:
     return _build_m06_variant(name, polarized, _visited)
-  try:
-    pylibxc = _import_pylibxc()
-  except Exception as e:
-    raise RuntimeError(
-      "The 'pylibxc' module is required to allocate LibXC functionals. "
-      "Install it via the 'pylibxc7' wheels on PyPI or a local build."
-    ) from e
   try:
     from . import helper as _helper
   except Exception as e:
@@ -379,7 +356,7 @@ def get_params(name, polarized, *ext_params, _visited=None):
     ) from e
 
   # 1) Extract metadata from the actual functional
-  func_actual = pylibxc.LibXCFunctional(name, int(polarized) + 1)
+  func_actual = LibXCFunctional(name, int(polarized) + 1)
   if ext_params:
     func_actual.set_ext_params(ext_params)
   xc_func_ptr_actual = ctypes.cast(func_actual.xc_func, ctypes.c_void_p).value
@@ -390,7 +367,7 @@ def get_params(name, polarized, *ext_params, _visited=None):
   alias = PARAM_ALIASES.get(name)
   if alias is not None:
     try:
-      func_alias = pylibxc.LibXCFunctional(alias, int(polarized) + 1)
+      func_alias = LibXCFunctional(alias, int(polarized) + 1)
       if ext_params:
         func_alias.set_ext_params(ext_params)
       xc_func_ptr_alias = ctypes.cast(func_alias.xc_func, ctypes.c_void_p).value
@@ -442,7 +419,7 @@ def get_params(name, polarized, *ext_params, _visited=None):
           child_number = child_dict.get("number")
           if child_number is not None:
             try:
-              temp_func = pylibxc.LibXCFunctional(child_number, int(polarized) + 1)
+              temp_func = LibXCFunctional(child_number, int(polarized) + 1)
               child_dict["name"] = child_dict.get("libxc_name", temp_func.get_name())
             except Exception:
               child_dict["name"] = child_dict.get("libxc_name", f"xc_{child_number}")
